# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [5.1.0] - 2022-05-31

### Added

- Added gracefull shutdown capabilities for SIGINT, SIGTERM and SIGQUIT signals

## [5.0.0] - 2021-09-10

### Added

- New log to inform when broker send an `ERROR` frame.
- Start to manage db connections, honoring the `CONN_MAX_AGE` defined in Django app settings.

### Fixed

- Update `stomp.py` from `6.0.0` to `~=7.0.0`.
- Update `tenacity` from `~=6.0` to  `~=8.0`.

## [4.2.1] - 2021-04-07

### Changed

- Pin `stomp.py` to `6.0.0` version to avoid its breaking changes.

## [4.2.0] - 2020-08-13

### Changed

- Logs level from `tenacity` to `WARNING`

### Fixed

- Fix lost messages that was sent within a `STOMP` transaction when reconnections with the broker is necessary.

## [4.1.2] - 2020-06-22

### Changed

- Standard headers generated by `django-stomp` (`tshoot-destination`, `x-dead-letter-routing-key` and `x-dead-letter-exchange`) cannot be overwritten.

### Fixed

- Properly handling of unsafe headers before a message is sent.

## [4.1.1] - 2020-06-16

### Changed

- Removal of unsafe headers (such as `message-id`) before a message is publish to broker.

### Fixed

- Fix consumers that was stuck with messages without the `correlation-id` header when `STOMP_CORRELATION_ID_REQUIRED` is set to `true`.

## [4.1.0] - 2020-05-26

### Added

- New command (`ack_all_messages`) to clean all messages from a queue.

## [4.0.1] - 2020-05-22

### Fixed

- Remove the unnecessary creation of a [durable topic subscriber](https://activemq.apache.org/how-do-durable-queues-and-topics-work) in `ActiveMQ`.

## [4.0.0] - 2020-05-11

### Changed

- Parameter `STOMP_OUTGOING_HEARTBIT` to `STOMP_OUTGOING_HEARTBEAT`.
- Parameter `STOMP_INCOMING_HEARTBIT` to `STOMP_INCOMING_HEARTBEAT`.
- The default interval values for incoming/outgoing heart-beats is 10s.

## [3.2.0] - 2020-05-11

### Changed

- Command `move_messages` to move messages between two different brokers.

## [3.1.0] - 2020-05-01

### Added

- Logs that tells the parameters used in the connection with a broker.

## [3.0.0] - 2020-04-27

### Added

- New settings parameter (`STOMP_PROCESS_MSG_ON_BACKGROUND`) that enables the message processing to occur in background, allowing any other broker-consumer communication (such as heartbeats) to still take place. This behaviour is enabled by default.
- New optional settings parameter (`STOMP_PROCESS_MSG_WORKERS`) that controls the maximum number of worker threads (that process the message in the background) to be spawned.

### Changed

- Enable [STOMP heart-beats](https://stomp.github.io/stomp-specification-1.1.html#Heart-beating) by default setting an interval of 6s for incoming and outgoing heart-beats.

## [2.1.1] - 2020-04-13

### Removed

- `CustomStompConnection11`, since it's now possible to send a custom header when we send a `NACK` action with the standard `StompConnection` from `stomp.py`.

## [2.1.0] - 2020-04-06

### Added

- New settings parameter (`STOMP_CORRELATION_ID_REQUIRED`) that control if a consumer require messages to contain a `correlation-id` header. The default value is `true`.

## [2.0.1] - 2020-03-10

### Added

- New settings parameter (`STOMP_SERVER_VHOST`) that allow the consumer/publisher to connect with a server virtual host.

## [2.0.0] - 2020-03-09

### Added

- A mechanism to mimic the [Virtual Topic](https://activemq.apache.org/virtual-destinations) behaviour from `ActiveMQ` in `RabbitMQ`.

### Fixed

- Pin `stomp.py` to `~=6.0`

## [1.0.4] - 2020-01-23

### Fixed

- Fix the connection parameters to really consider zero values.

## [1.0.3] - 2020-01-23

### Fixed

- Fix a helper function to correctly deal with `0` value when it's given.

## [1.0.2] - 2020-01-07

### Changed

- Pin `request-id-django-log` to `0.1.1` version.
- Pin `stomp.py` to `~=4.1`.
- Pin `tenacity` to `~=6.0`.

[5.1.0]: https://github.com/juntossomosmais/django-stomp/compare/5.0.0...5.1.0
[5.0.0]: https://github.com/juntossomosmais/django-stomp/compare/4.2.1...5.0.0
[4.2.1]: https://github.com/juntossomosmais/django-stomp/compare/4.2.0...4.2.1
[4.2.0]: https://github.com/juntossomosmais/django-stomp/compare/4.1.2...4.2.0
[4.1.2]: https://github.com/juntossomosmais/django-stomp/compare/4.1.1...4.1.2
[4.1.1]: https://github.com/juntossomosmais/django-stomp/compare/4.1.0...4.1.1
[4.1.0]: https://github.com/juntossomosmais/django-stomp/compare/4.0.1...4.1.0
[4.0.1]: https://github.com/juntossomosmais/django-stomp/compare/4.0.0...4.0.1
[4.0.0]: https://github.com/juntossomosmais/django-stomp/compare/3.2.0...4.0.0
[3.2.0]: https://github.com/juntossomosmais/django-stomp/compare/3.1.0...3.2.0
[3.1.0]: https://github.com/juntossomosmais/django-stomp/compare/3.0.0...3.1.0
[3.0.0]: https://github.com/juntossomosmais/django-stomp/compare/2.1.1...3.0.0
[2.1.1]: https://github.com/juntossomosmais/django-stomp/compare/2.1.0...2.1.1
[2.1.0]: https://github.com/juntossomosmais/django-stomp/compare/2.0.1...2.1.0
[2.0.1]: https://github.com/juntossomosmais/django-stomp/compare/2.0.0...2.0.1
[2.0.0]: https://github.com/juntossomosmais/django-stomp/compare/1.0.4...2.0.0
[1.0.4]: https://github.com/juntossomosmais/django-stomp/compare/1.0.3...1.0.4
[1.0.3]: https://github.com/juntossomosmais/django-stomp/compare/1.0.2...1.0.3
[1.0.2]: https://github.com/juntossomosmais/django-stomp/compare/1.0.1...1.0.2
[1.0.1]: https://github.com/juntossomosmais/django-stomp/tree/1.0.1
